@@ -1,5 +1,5 @@
-from typing import Optional
 import logging
+from typing import Optional
 
 from .device import Device
 from .utils import Client
@@ -14,7 +14,7 @@ class LeakSensor(Device):
 
     def __init__(self, device_id: int, client: Client):
         super().__init__(device_id, client)
-        self._leak = None
+        self._leak: Optional[bool] = None
 
     def get_leak(self) -> Optional[bool]:
         """
@@ -36,9 +36,9 @@ class LeakSensor(Device):
 
     def _update_parser(self, event: dict):
         """
-        Called when ``_async_update_state`` returns info
+        Called when ``Client._async_update_state`` returns info
 
-        ``event`` dict passed in from ``_async_update_state``
+        ``event`` dict passed in from ``Client._async_update_state``
         """
         _LOGGER.info("Updating Sensor")
 
