@@ -134,7 +134,10 @@ class Thermostat(Device):
         self._cooling_setpoint = float_to_int(attrs.get("cooling_setpoint"))
         self._heating_setpoint = float_to_int(attrs.get("heating_setpoint"))
 
-        self._current_humidity = float_to_int(attrs.get("current_humidity"))
+        temp_humidity = float_to_int(attrs.get("current_humidity"))
+        self._current_humidity = (
+            int(temp_humidity) if int(temp_humidity) > 0 else self._current_humidity
+        )
 
         self._mode = attrs["mode"]
         self._fan_mode = attrs.get("fan_mode")
@@ -149,19 +152,23 @@ class Thermostat(Device):
         last_read_state = str(event.get("last_read_state"))
 
         if event.get("name") == "current_humidity":
-            self._current_humidity = int(last_read_state)
+            self._current_humidity = (
+                int(last_read_state)
+                if int(last_read_state) > 0
+                else self._current_humidity
+            )
 
-        if event.get("name") == "current_temp":
+        elif event.get("name") == "current_temp":
             self._current_temp = int(last_read_state)
 
-        if event.get("name") == "heating_setpoint":
+        elif event.get("name") == "heating_setpoint":
             self._heating_setpoint = int(last_read_state)
 
-        if event.get("name") == "cooling_setpoint":
+        elif event.get("name") == "cooling_setpoint":
             self._cooling_setpoint = int(last_read_state)
 
-        if event.get("name") == "mode":
+        elif event.get("name") == "mode":
             self._mode = last_read_state
 
-        if event.get("name") == "fan_mode":
+        elif event.get("name") == "fan_mode":
             self._fan_mode = last_read_state
